@@ -194,6 +194,34 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CheckIdNameDate(self, request):
+        """本接口用于校验姓名、身份证号、身份证有效期的真实性和一致性。
+
+        :param request: Request instance for CheckIdNameDate.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.CheckIdNameDateRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.CheckIdNameDateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CheckIdNameDate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CheckIdNameDateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CheckPhoneAndName(self, request):
         """手机号二要素核验接口用于校验手机号和姓名的真实性和一致性，支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
@@ -250,6 +278,35 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DetectReflectLivenessAndCompare(self, request):
+        """使用活体比对（光线）SDK生成的数据包检测活体，并和传入的图片进行比对。
+        图片和SDK生成的数据内容必须存储在腾讯云COS，COS Bucket所在的Region需要和本接口请求的Region保持一致，推荐使用生成上传链接接口来完成资源传递。
+
+        :param request: Request instance for DetectReflectLivenessAndCompare.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.DetectReflectLivenessAndCompareRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.DetectReflectLivenessAndCompareResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DetectReflectLivenessAndCompare", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DetectReflectLivenessAndCompareResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def EncryptedPhoneVerification(self, request):
         """本接口用于校验手机号、姓名和身份证号的真实性和一致性，入参支持MD5加密传输。
 
@@ -558,6 +615,34 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetWeChatBillDetails(self, request):
+        """查询微信渠道服务（微信小程序、微信原生H5、微信普通H5）的账单明细及计费状态。
+
+        :param request: Request instance for GetWeChatBillDetails.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.GetWeChatBillDetailsRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.GetWeChatBillDetailsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetWeChatBillDetails", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetWeChatBillDetailsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def IdCardOCRVerification(self, request):
         """本接口用于校验姓名和身份证号的真实性和一致性，您可以通过输入姓名和身份证号或传入身份证人像面照片提供所需验证信息。
 
@@ -727,7 +812,7 @@ class FaceidClient(AbstractClient):
 
 
     def MinorsVerification(self, request):
-        """未成年人守护接口是通过传入手机号或姓名和身份证号，结合权威数据源和腾讯健康守护可信模型，判断该信息是否真实且年满18周岁。腾讯健康守护可信模型覆盖了上十亿手机库源，覆盖率高、准确率高，如果不在库中的手机号，还可以通过姓名+身份证进行兜底验证。
+        """通过传入手机号或姓名和身份证号，结合权威数据源和腾讯健康守护可信模型，判断该信息是否真实且年满18周岁。腾讯健康守护可信模型覆盖了上十亿手机库源，覆盖率高、准确率高，如果不在库中的手机号，还可以通过姓名+身份证进行兜底验证。
 
         :param request: Request instance for MinorsVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.MinorsVerificationRequest`
